{#
# This file is part of Invenio.
# Copyright (C) 2015 CERN.
#
# Invenio is free software; you can redistribute it
# and/or modify it under the terms of the GNU General Public License as
# published by the Free Software Foundation; either version 2 of the
# License, or (at your option) any later version.
#
# Invenio is distributed in the hope that it will be
# useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Invenio; if not, write to the
# Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
# MA 02111-1307, USA.
#
# In applying this license, CERN does not
# waive the privileges and immunities granted to it by virtue of its status
# as an Intergovernmental Organization or submit itself to any jurisdiction.
#}

{% extends config.THEME_SETTINGS_TEMPLATE %}

{% set panel_icon="fa fa-wrench" %}
{% set panel_title="Form example with message flashing" %}

{% block settings_form %}
<form action="/settings/1">
<div class="form-group">
    <label class="control-label" for="password">{{_('Example Field 1')}}</label>
    <input class="form-control" type="text"></input>
</div>
<div class="form-group">
    <label class="control-label" for="password">{{_('Example Field 2')}}</label>
    <input class="form-control" type="text"></input>
</div>
<div class="form-actions">
    <button type="submit" class="btn btn-primary">{{_('Submit')}}</button>
</div>
</form>
{% endblock settings_form %}
